ffi_reactor_step

Function ffi_reactor_step 

#[unsafe(no_mangle)]
pub unsafe fn ffi_reactor_step(responses_ptr: FFIBufPtr) -> FFIBufPtr
ffi_reactor_step is called by the host to advance the reactor forward.

Panics

Panics if the host passes in an invalid pointer.

Safety

The host must pass in a valid pointer to a serialized Responses object.